/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This file was generated.
 *  with google-apis-code-generator 1.2.0 (build: 1969-12-31 15:59:59 PST)
 */

package com.google.api.services.glass;

import com.google.api.client.googleapis.GoogleUtils;
import com.google.api.client.googleapis.services.AbstractGoogleClientRequest;
import com.google.api.client.googleapis.services.GoogleClientRequestInitializer;
import com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient;
import com.google.api.client.googleapis.subscriptions.SubscriptionStore;
import com.google.api.client.http.HttpRequestInitializer;
import com.google.api.client.http.HttpTransport;
import com.google.api.client.json.JsonFactory;
import com.google.api.client.json.JsonObjectParser;
import com.google.common.base.Preconditions;

/**
 * Service definition for Glass (v1).
 *
 * <p>
 * API for interacting with Glass users via the timeline.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://devsite.googleplex.com/glass" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link GlassRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * <p>
 * Upgrade warning: this class now extends {@link AbstractGoogleJsonClient}, whereas in prior
 * version 1.8 it extended {@link com.google.api.client.googleapis.services.GoogleClient}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class Glass extends AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    Preconditions.checkState(GoogleUtils.VERSION.equals("1.13.0-beta-SNAPSHOT"),
        "You are currently running with version %s of google-api-client. " +
        "You need version 1.13.0-beta-SNAPSHOT of google-api-client to run version " +
        "1.13.0-beta-SNAPSHOT of the Glass Mirror API library.", GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "glass/v1/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   * @deprecated (scheduled to be removed in 1.13)
   */
  @Deprecated
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport
   * @param jsonFactory JSON factory
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public Glass(HttpTransport transport, JsonFactory jsonFactory,
      HttpRequestInitializer httpRequestInitializer) {
    super(transport,
        jsonFactory,
        DEFAULT_ROOT_URL,
        DEFAULT_SERVICE_PATH,
        httpRequestInitializer,
        false);
  }

  /**
   * @param transport HTTP transport
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @param rootUrl root URL of the service
   * @param servicePath service path
   * @param jsonObjectParser JSON object parser
   * @param googleClientRequestInitializer Google request initializer or {@code null} for none
   * @param applicationName application name to be sent in the User-Agent header of requests or
   *        {@code null} for none
   * @param subscriptionStore subscription store or {@code null} for none
   * @param suppressPatternChecks whether discovery pattern checks should be suppressed on required
   *        parameters
   */
  Glass(HttpTransport transport,
      HttpRequestInitializer httpRequestInitializer,
      String rootUrl,
      String servicePath,
      JsonObjectParser jsonObjectParser,
      GoogleClientRequestInitializer googleClientRequestInitializer,
      String applicationName,
      SubscriptionStore subscriptionStore,
      boolean suppressPatternChecks) {
    super(transport,
        httpRequestInitializer,
        rootUrl,
        servicePath,
        jsonObjectParser,
        googleClientRequestInitializer,
        applicationName,
        subscriptionStore,
        suppressPatternChecks);
  }

  @Override
  protected void initialize(AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Locations collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Glass glass = new Glass(...);}
   *   {@code Glass.Locations.List request = glass.locations().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Locations locations() {
    return new Locations();
  }

  /**
   * The "locations" collection of methods.
   */
  public class Locations {

    /**
     * Gets a single location by id.
     *
     * Create a request for the method "locations.get".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param id The ID of the location or latest for the last known location.
     * @return the request
     */
    public Get get(String id) throws java.io.IOException {
      Get result = new Get(id);
      initialize(result);
      return result;
    }

    public class Get extends GlassRequest<com.google.api.services.glass.model.Location> {

      private static final String REST_PATH = "locations/{id}";

      Get(String id) {
        super(Glass.this, "GET", REST_PATH, null, com.google.api.services.glass.model.Location.class);
        this.id = Preconditions.checkNotNull(id, "Required parameter id must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      /** The ID of the location or latest for the last known location. */
      @com.google.api.client.util.Key
      private String id;

      /** The ID of the location or latest for the last known location.
       */
      public String getId() {
        return id;
      }

      /** The ID of the location or latest for the last known location. */
      public Get setId(String id) {
        this.id = id;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the ShareTargets collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Glass glass = new Glass(...);}
   *   {@code Glass.ShareTargets.List request = glass.shareTargets().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public ShareTargets shareTargets() {
    return new ShareTargets();
  }

  /**
   * The "shareTargets" collection of methods.
   */
  public class ShareTargets {

    /**
     * Retrieves a list of share targets for the authenticated user.
     *
     * Create a request for the method "shareTargets.list".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends GlassRequest<com.google.api.services.glass.model.ShareTargetsListResponse> {

      private static final String REST_PATH = "shareTargets";

      List() {
        super(Glass.this, "GET", REST_PATH, null, com.google.api.services.glass.model.ShareTargetsListResponse.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

    }
    /**
     * Updates a share target in place.
     *
     * Create a request for the method "shareTargets.update".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Update#execute()} method to invoke the remote operation.
     *
     * @param id The ID of the share target.
     * @param content the {@link com.google.api.services.glass.model.Entity}
     * @return the request
     */
    public Update update(String id, com.google.api.services.glass.model.Entity content) throws java.io.IOException {
      Update result = new Update(id, content);
      initialize(result);
      return result;
    }

    public class Update extends GlassRequest<com.google.api.services.glass.model.Entity> {

      private static final String REST_PATH = "shareTargets/{id}";

      Update(String id, com.google.api.services.glass.model.Entity content) {
        super(Glass.this, "PUT", REST_PATH, content, com.google.api.services.glass.model.Entity.class);
        this.id = Preconditions.checkNotNull(id, "Required parameter id must be specified.");
      }

      @Override
      public Update setUserIp(String userIp) {
        return (Update) super.setUserIp(userIp);
      }

      @Override
      public Update setOauthToken(String oauthToken) {
        return (Update) super.setOauthToken(oauthToken);
      }

      @Override
      public Update setQuotaUser(String quotaUser) {
        return (Update) super.setQuotaUser(quotaUser);
      }

      @Override
      public Update setKey(String key) {
        return (Update) super.setKey(key);
      }

      @Override
      public Update setPrettyPrint(Boolean prettyPrint) {
        return (Update) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Update setAlt(String alt) {
        return (Update) super.setAlt(alt);
      }

      @Override
      public Update setFields(String fields) {
        return (Update) super.setFields(fields);
      }

      /** The ID of the share target. */
      @com.google.api.client.util.Key
      private String id;

      /** The ID of the share target.
       */
      public String getId() {
        return id;
      }

      /** The ID of the share target. */
      public Update setId(String id) {
        this.id = id;
        return this;
      }

    }
    /**
     * Gets a single share target by id.
     *
     * Create a request for the method "shareTargets.get".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param id The ID of the share target.
     * @return the request
     */
    public Get get(String id) throws java.io.IOException {
      Get result = new Get(id);
      initialize(result);
      return result;
    }

    public class Get extends GlassRequest<com.google.api.services.glass.model.Entity> {

      private static final String REST_PATH = "shareTargets/{id}";

      Get(String id) {
        super(Glass.this, "GET", REST_PATH, null, com.google.api.services.glass.model.Entity.class);
        this.id = Preconditions.checkNotNull(id, "Required parameter id must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      /** The ID of the share target. */
      @com.google.api.client.util.Key
      private String id;

      /** The ID of the share target.
       */
      public String getId() {
        return id;
      }

      /** The ID of the share target. */
      public Get setId(String id) {
        this.id = id;
        return this;
      }

    }
    /**
     * Inserts a new share target.
     *
     * Create a request for the method "shareTargets.insert".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param content the {@link com.google.api.services.glass.model.Entity}
     * @return the request
     */
    public Insert insert(com.google.api.services.glass.model.Entity content) throws java.io.IOException {
      Insert result = new Insert(content);
      initialize(result);
      return result;
    }

    public class Insert extends GlassRequest<com.google.api.services.glass.model.Entity> {

      private static final String REST_PATH = "shareTargets";

      Insert(com.google.api.services.glass.model.Entity content) {
        super(Glass.this, "POST", REST_PATH, content, com.google.api.services.glass.model.Entity.class);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

    }
    /**
     * Deletes a share target.
     *
     * Create a request for the method "shareTargets.delete".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
     *
     * @param id The ID of the share target.
     * @return the request
     */
    public Delete delete(String id) throws java.io.IOException {
      Delete result = new Delete(id);
      initialize(result);
      return result;
    }

    public class Delete extends GlassRequest<Void> {

      private static final String REST_PATH = "shareTargets/{id}";

      Delete(String id) {
        super(Glass.this, "DELETE", REST_PATH, null, Void.class);
        this.id = Preconditions.checkNotNull(id, "Required parameter id must be specified.");
      }

      @Override
      public Delete setUserIp(String userIp) {
        return (Delete) super.setUserIp(userIp);
      }

      @Override
      public Delete setOauthToken(String oauthToken) {
        return (Delete) super.setOauthToken(oauthToken);
      }

      @Override
      public Delete setQuotaUser(String quotaUser) {
        return (Delete) super.setQuotaUser(quotaUser);
      }

      @Override
      public Delete setKey(String key) {
        return (Delete) super.setKey(key);
      }

      @Override
      public Delete setPrettyPrint(Boolean prettyPrint) {
        return (Delete) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Delete setAlt(String alt) {
        return (Delete) super.setAlt(alt);
      }

      @Override
      public Delete setFields(String fields) {
        return (Delete) super.setFields(fields);
      }

      /** The ID of the share target. */
      @com.google.api.client.util.Key
      private String id;

      /** The ID of the share target.
       */
      public String getId() {
        return id;
      }

      /** The ID of the share target. */
      public Delete setId(String id) {
        this.id = id;
        return this;
      }

    }
    /**
     * Updates a share target in place. This method supports patch semantics.
     *
     * Create a request for the method "shareTargets.patch".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Patch#execute()} method to invoke the remote operation.
     *
     * @param id The ID of the share target.
     * @param content the {@link com.google.api.services.glass.model.Entity}
     * @return the request
     */
    public Patch patch(String id, com.google.api.services.glass.model.Entity content) throws java.io.IOException {
      Patch result = new Patch(id, content);
      initialize(result);
      return result;
    }

    public class Patch extends GlassRequest<com.google.api.services.glass.model.Entity> {

      private static final String REST_PATH = "shareTargets/{id}";

      Patch(String id, com.google.api.services.glass.model.Entity content) {
        super(Glass.this, "PATCH", REST_PATH, content, com.google.api.services.glass.model.Entity.class);
        this.id = Preconditions.checkNotNull(id, "Required parameter id must be specified.");
      }

      @Override
      public Patch setUserIp(String userIp) {
        return (Patch) super.setUserIp(userIp);
      }

      @Override
      public Patch setOauthToken(String oauthToken) {
        return (Patch) super.setOauthToken(oauthToken);
      }

      @Override
      public Patch setQuotaUser(String quotaUser) {
        return (Patch) super.setQuotaUser(quotaUser);
      }

      @Override
      public Patch setKey(String key) {
        return (Patch) super.setKey(key);
      }

      @Override
      public Patch setPrettyPrint(Boolean prettyPrint) {
        return (Patch) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Patch setAlt(String alt) {
        return (Patch) super.setAlt(alt);
      }

      @Override
      public Patch setFields(String fields) {
        return (Patch) super.setFields(fields);
      }

      /** The ID of the share target. */
      @com.google.api.client.util.Key
      private String id;

      /** The ID of the share target.
       */
      public String getId() {
        return id;
      }

      /** The ID of the share target. */
      public Patch setId(String id) {
        this.id = id;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Attachments collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Glass glass = new Glass(...);}
   *   {@code Glass.Attachments.List request = glass.attachments().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Attachments attachments() {
    return new Attachments();
  }

  /**
   * The "attachments" collection of methods.
   */
  public class Attachments {

    /**
     * Gets an attachment by id.
     *
     * Create a request for the method "attachments.get".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param itemId The ID of the timeline item the attachment is associated with.
     * @param attachmentId The ID of the attachment.
     * @return the request
     */
    public Get get(String itemId, String attachmentId) throws java.io.IOException {
      Get result = new Get(itemId, attachmentId);
      initialize(result);
      return result;
    }

    public class Get extends GlassRequest<com.google.api.services.glass.model.Empty> {

      private static final String REST_PATH = "attachments/{itemId}/{attachmentId}";

      Get(String itemId, String attachmentId) {
        super(Glass.this, "GET", REST_PATH, null, com.google.api.services.glass.model.Empty.class);
        this.itemId = Preconditions.checkNotNull(itemId, "Required parameter itemId must be specified.");
        this.attachmentId = Preconditions.checkNotNull(attachmentId, "Required parameter attachmentId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      /** The ID of the timeline item the attachment is associated with. */
      @com.google.api.client.util.Key
      private String itemId;

      /** The ID of the timeline item the attachment is associated with.
       */
      public String getItemId() {
        return itemId;
      }

      /** The ID of the timeline item the attachment is associated with. */
      public Get setItemId(String itemId) {
        this.itemId = itemId;
        return this;
      }

      /** The ID of the attachment. */
      @com.google.api.client.util.Key
      private String attachmentId;

      /** The ID of the attachment.
       */
      public String getAttachmentId() {
        return attachmentId;
      }

      /** The ID of the attachment. */
      public Get setAttachmentId(String attachmentId) {
        this.attachmentId = attachmentId;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Subscriptions collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Glass glass = new Glass(...);}
   *   {@code Glass.Subscriptions.List request = glass.subscriptions().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Subscriptions subscriptions() {
    return new Subscriptions();
  }

  /**
   * The "subscriptions" collection of methods.
   */
  public class Subscriptions {

    /**
     * Retrieves a list of subscriptions for the authenticated user and service.
     *
     * Create a request for the method "subscriptions.list".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends GlassRequest<com.google.api.services.glass.model.SubscriptionsListResponse> {

      private static final String REST_PATH = "subscriptions";

      List() {
        super(Glass.this, "GET", REST_PATH, null, com.google.api.services.glass.model.SubscriptionsListResponse.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

    }
    /**
     * Deletes a subscription.
     *
     * Create a request for the method "subscriptions.delete".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
     *
     * @param id The ID of the subscription.
     * @return the request
     */
    public Delete delete(String id) throws java.io.IOException {
      Delete result = new Delete(id);
      initialize(result);
      return result;
    }

    public class Delete extends GlassRequest<Void> {

      private static final String REST_PATH = "subscriptions/{id}";

      Delete(String id) {
        super(Glass.this, "DELETE", REST_PATH, null, Void.class);
        this.id = Preconditions.checkNotNull(id, "Required parameter id must be specified.");
      }

      @Override
      public Delete setUserIp(String userIp) {
        return (Delete) super.setUserIp(userIp);
      }

      @Override
      public Delete setOauthToken(String oauthToken) {
        return (Delete) super.setOauthToken(oauthToken);
      }

      @Override
      public Delete setQuotaUser(String quotaUser) {
        return (Delete) super.setQuotaUser(quotaUser);
      }

      @Override
      public Delete setKey(String key) {
        return (Delete) super.setKey(key);
      }

      @Override
      public Delete setPrettyPrint(Boolean prettyPrint) {
        return (Delete) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Delete setAlt(String alt) {
        return (Delete) super.setAlt(alt);
      }

      @Override
      public Delete setFields(String fields) {
        return (Delete) super.setFields(fields);
      }

      /** The ID of the subscription. */
      @com.google.api.client.util.Key
      private String id;

      /** The ID of the subscription.
       */
      public String getId() {
        return id;
      }

      /** The ID of the subscription. */
      public Delete setId(String id) {
        this.id = id;
        return this;
      }

    }
    /**
     * Creates a new subscription.
     *
     * Create a request for the method "subscriptions.insert".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param content the {@link com.google.api.services.glass.model.Subscription}
     * @return the request
     */
    public Insert insert(com.google.api.services.glass.model.Subscription content) throws java.io.IOException {
      Insert result = new Insert(content);
      initialize(result);
      return result;
    }

    public class Insert extends GlassRequest<com.google.api.services.glass.model.Subscription> {

      private static final String REST_PATH = "subscriptions";

      Insert(com.google.api.services.glass.model.Subscription content) {
        super(Glass.this, "POST", REST_PATH, content, com.google.api.services.glass.model.Subscription.class);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

    }
    /**
     * Updates an existing subscription in place.
     *
     * Create a request for the method "subscriptions.update".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Update#execute()} method to invoke the remote operation.
     *
     * @param id The ID of the subscription.
     * @param content the {@link com.google.api.services.glass.model.Subscription}
     * @return the request
     */
    public Update update(String id, com.google.api.services.glass.model.Subscription content) throws java.io.IOException {
      Update result = new Update(id, content);
      initialize(result);
      return result;
    }

    public class Update extends GlassRequest<com.google.api.services.glass.model.Subscription> {

      private static final String REST_PATH = "subscriptions/{id}";

      Update(String id, com.google.api.services.glass.model.Subscription content) {
        super(Glass.this, "PUT", REST_PATH, content, com.google.api.services.glass.model.Subscription.class);
        this.id = Preconditions.checkNotNull(id, "Required parameter id must be specified.");
      }

      @Override
      public Update setUserIp(String userIp) {
        return (Update) super.setUserIp(userIp);
      }

      @Override
      public Update setOauthToken(String oauthToken) {
        return (Update) super.setOauthToken(oauthToken);
      }

      @Override
      public Update setQuotaUser(String quotaUser) {
        return (Update) super.setQuotaUser(quotaUser);
      }

      @Override
      public Update setKey(String key) {
        return (Update) super.setKey(key);
      }

      @Override
      public Update setPrettyPrint(Boolean prettyPrint) {
        return (Update) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Update setAlt(String alt) {
        return (Update) super.setAlt(alt);
      }

      @Override
      public Update setFields(String fields) {
        return (Update) super.setFields(fields);
      }

      /** The ID of the subscription. */
      @com.google.api.client.util.Key
      private String id;

      /** The ID of the subscription.
       */
      public String getId() {
        return id;
      }

      /** The ID of the subscription. */
      public Update setId(String id) {
        this.id = id;
        return this;
      }

    }

  }

  /**
   * An accessor for creating requests from the Timeline collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Glass glass = new Glass(...);}
   *   {@code Glass.Timeline.List request = glass.timeline().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Timeline timeline() {
    return new Timeline();
  }

  /**
   * The "timeline" collection of methods.
   */
  public class Timeline {

    /**
     * Retrieves a list of timeline items for the authenticated user.
     *
     * Create a request for the method "timeline.list".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends GlassRequest<com.google.api.services.glass.model.TimelineListResponse> {

      private static final String REST_PATH = "timeline";

      List() {
        super(Glass.this, "GET", REST_PATH, null, com.google.api.services.glass.model.TimelineListResponse.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setUserIp(String userIp) {
        return (List) super.setUserIp(userIp);
      }

      @Override
      public List setOauthToken(String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setQuotaUser(String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setKey(String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setPrettyPrint(Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setAlt(String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(String fields) {
        return (List) super.setFields(fields);
      }

      /** If true, only pinned items will be returned. */
      @com.google.api.client.util.Key
      private Boolean pinnedOnly;

      /** If true, only pinned items will be returned.
       */
      public Boolean getPinnedOnly() {
        return pinnedOnly;
      }

      /** If true, only pinned items will be returned. */
      public List setPinnedOnly(Boolean pinnedOnly) {
        this.pinnedOnly = pinnedOnly;
        return this;
      }

      /** Token for the page of results to return. */
      @com.google.api.client.util.Key
      private String pageToken;

      /** Token for the page of results to return.
       */
      public String getPageToken() {
        return pageToken;
      }

      /** Token for the page of results to return. */
      public List setPageToken(String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** The maximum number of items to include in the response, used for paging. */
      @com.google.api.client.util.Key
      private Long maxResults;

      /** The maximum number of items to include in the response, used for paging.
       */
      public Long getMaxResults() {
        return maxResults;
      }

      /** The maximum number of items to include in the response, used for paging. */
      public List setMaxResults(Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

    }
    /**
     * Updates a timeline item in place.
     *
     * Create a request for the method "timeline.update".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Update#execute()} method to invoke the remote operation.
     *
     * @param id The ID of the timeline item.
     * @param content the {@link com.google.api.services.glass.model.TimelineItem}
     * @return the request
     */
    public Update update(String id, com.google.api.services.glass.model.TimelineItem content) throws java.io.IOException {
      Update result = new Update(id, content);
      initialize(result);
      return result;
    }

    /**
     * Updates a timeline item in place.
     *
     * Create a request for the method "timeline.update".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Update#execute()} method to invoke the remote operation.
     *
     * <p>
     * This method should be used for uploading media content.
     * </p>
     *
     * @param id The ID of the timeline item.
     * @param content the {@link com.google.api.services.glass.model.TimelineItem} media metadata or {@code null} if none
     * @param mediaContent The media HTTP content or {@code null} if none.
     * @return the request
     * @throws java.io.IOException if the initialization of the request fails
     */
    public Update update(String id, com.google.api.services.glass.model.TimelineItem content,
        com.google.api.client.http.AbstractInputStreamContent mediaContent) throws java.io.IOException {
      Update result = new Update(id, content, mediaContent);
      initialize(result);
      return result;
    }

    public class Update extends GlassRequest<com.google.api.services.glass.model.TimelineItem> {

      private static final String REST_PATH = "timeline/{id}";

      Update(String id, com.google.api.services.glass.model.TimelineItem content) {
        super(Glass.this, "PUT", REST_PATH, content, com.google.api.services.glass.model.TimelineItem.class);
        this.id = Preconditions.checkNotNull(id, "Required parameter id must be specified.");
      }

      Update(String id, com.google.api.services.glass.model.TimelineItem content,
          com.google.api.client.http.AbstractInputStreamContent mediaContent) {
        super(Glass.this, "PUT", "/upload/" + getServicePath() + REST_PATH, content, com.google.api.services.glass.model.TimelineItem.class);
        this.id = Preconditions.checkNotNull(id, "Required parameter id must be specified.");
        initializeMediaUpload(mediaContent);
      }

      @Override
      public Update setUserIp(String userIp) {
        return (Update) super.setUserIp(userIp);
      }

      @Override
      public Update setOauthToken(String oauthToken) {
        return (Update) super.setOauthToken(oauthToken);
      }

      @Override
      public Update setQuotaUser(String quotaUser) {
        return (Update) super.setQuotaUser(quotaUser);
      }

      @Override
      public Update setKey(String key) {
        return (Update) super.setKey(key);
      }

      @Override
      public Update setPrettyPrint(Boolean prettyPrint) {
        return (Update) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Update setAlt(String alt) {
        return (Update) super.setAlt(alt);
      }

      @Override
      public Update setFields(String fields) {
        return (Update) super.setFields(fields);
      }

      /** The ID of the timeline item. */
      @com.google.api.client.util.Key
      private String id;

      /** The ID of the timeline item.
       */
      public String getId() {
        return id;
      }

      /** The ID of the timeline item. */
      public Update setId(String id) {
        this.id = id;
        return this;
      }

    }
    /**
     * Gets a single timeline item by id.
     *
     * Create a request for the method "timeline.get".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param id The ID of the timeline item.
     * @return the request
     */
    public Get get(String id) throws java.io.IOException {
      Get result = new Get(id);
      initialize(result);
      return result;
    }

    public class Get extends GlassRequest<com.google.api.services.glass.model.TimelineItem> {

      private static final String REST_PATH = "timeline/{id}";

      Get(String id) {
        super(Glass.this, "GET", REST_PATH, null, com.google.api.services.glass.model.TimelineItem.class);
        this.id = Preconditions.checkNotNull(id, "Required parameter id must be specified.");
      initializeMediaDownload();
      }

      /** Upgrade warning: in prior version 1.8 this method was called {@code download}. */
      @Override
      public void executeMediaAndDownloadTo(java.io.OutputStream outputStream) throws java.io.IOException {
        super.executeMediaAndDownloadTo(outputStream);
      }

      @Override
      public java.io.InputStream executeMediaAsInputStream() throws java.io.IOException {
        return super.executeMediaAsInputStream();
      }

      @Override
      public com.google.api.client.http.HttpResponse executeMedia() throws java.io.IOException {
        return super.executeMedia();
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setUserIp(String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      @Override
      public Get setOauthToken(String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setQuotaUser(String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setKey(String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setPrettyPrint(Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setAlt(String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(String fields) {
        return (Get) super.setFields(fields);
      }

      /** The ID of the timeline item. */
      @com.google.api.client.util.Key
      private String id;

      /** The ID of the timeline item.
       */
      public String getId() {
        return id;
      }

      /** The ID of the timeline item. */
      public Get setId(String id) {
        this.id = id;
        return this;
      }

    }
    /**
     * Inserts a new item into the timeline.
     *
     * Create a request for the method "timeline.insert".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param content the {@link com.google.api.services.glass.model.TimelineItem}
     * @return the request
     */
    public Insert insert(com.google.api.services.glass.model.TimelineItem content) throws java.io.IOException {
      Insert result = new Insert(content);
      initialize(result);
      return result;
    }

    /**
     * Inserts a new item into the timeline.
     *
     * Create a request for the method "timeline.insert".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * <p>
     * This method should be used for uploading media content.
     * </p>
     *
     *
     * @param content the {@link com.google.api.services.glass.model.TimelineItem} media metadata or {@code null} if none
     * @param mediaContent The media HTTP content or {@code null} if none.
     * @return the request
     * @throws java.io.IOException if the initialization of the request fails
     */
    public Insert insert(com.google.api.services.glass.model.TimelineItem content,
        com.google.api.client.http.AbstractInputStreamContent mediaContent) throws java.io.IOException {
      Insert result = new Insert(content, mediaContent);
      initialize(result);
      return result;
    }

    public class Insert extends GlassRequest<com.google.api.services.glass.model.TimelineItem> {

      private static final String REST_PATH = "timeline";

      Insert(com.google.api.services.glass.model.TimelineItem content) {
        super(Glass.this, "POST", REST_PATH, content, com.google.api.services.glass.model.TimelineItem.class);
      }

      Insert(com.google.api.services.glass.model.TimelineItem content,
          com.google.api.client.http.AbstractInputStreamContent mediaContent) {
        super(Glass.this, "POST", "/upload/" + getServicePath() + REST_PATH, content, com.google.api.services.glass.model.TimelineItem.class);
        initializeMediaUpload(mediaContent);
      }

      @Override
      public Insert setUserIp(String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      @Override
      public Insert setOauthToken(String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setQuotaUser(String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setKey(String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setPrettyPrint(Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setAlt(String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(String fields) {
        return (Insert) super.setFields(fields);
      }

    }
    /**
     * Deletes a timeline item.
     *
     * Create a request for the method "timeline.delete".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
     *
     * @param timelineId The ID of the timeline item.
     * @return the request
     */
    public Delete delete(String timelineId) throws java.io.IOException {
      Delete result = new Delete(timelineId);
      initialize(result);
      return result;
    }

    public class Delete extends GlassRequest<Void> {

      private static final String REST_PATH = "timeline/{timelineId}";

      Delete(String timelineId) {
        super(Glass.this, "DELETE", REST_PATH, null, Void.class);
        this.timelineId = Preconditions.checkNotNull(timelineId, "Required parameter timelineId must be specified.");
      }

      @Override
      public Delete setUserIp(String userIp) {
        return (Delete) super.setUserIp(userIp);
      }

      @Override
      public Delete setOauthToken(String oauthToken) {
        return (Delete) super.setOauthToken(oauthToken);
      }

      @Override
      public Delete setQuotaUser(String quotaUser) {
        return (Delete) super.setQuotaUser(quotaUser);
      }

      @Override
      public Delete setKey(String key) {
        return (Delete) super.setKey(key);
      }

      @Override
      public Delete setPrettyPrint(Boolean prettyPrint) {
        return (Delete) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Delete setAlt(String alt) {
        return (Delete) super.setAlt(alt);
      }

      @Override
      public Delete setFields(String fields) {
        return (Delete) super.setFields(fields);
      }

      /** The ID of the timeline item. */
      @com.google.api.client.util.Key
      private String timelineId;

      /** The ID of the timeline item.
       */
      public String getTimelineId() {
        return timelineId;
      }

      /** The ID of the timeline item. */
      public Delete setTimelineId(String timelineId) {
        this.timelineId = timelineId;
        return this;
      }

    }
    /**
     * Updates a timeline item in place. This method supports patch semantics.
     *
     * Create a request for the method "timeline.patch".
     *
     * This request holds the parameters needed by the the glass server.  After setting any optional
     * parameters, call the {@link Patch#execute()} method to invoke the remote operation.
     *
     * @param id The ID of the timeline item.
     * @param content the {@link com.google.api.services.glass.model.TimelineItem}
     * @return the request
     */
    public Patch patch(String id, com.google.api.services.glass.model.TimelineItem content) throws java.io.IOException {
      Patch result = new Patch(id, content);
      initialize(result);
      return result;
    }

    public class Patch extends GlassRequest<com.google.api.services.glass.model.TimelineItem> {

      private static final String REST_PATH = "timeline/{id}";

      Patch(String id, com.google.api.services.glass.model.TimelineItem content) {
        super(Glass.this, "PATCH", REST_PATH, content, com.google.api.services.glass.model.TimelineItem.class);
        this.id = Preconditions.checkNotNull(id, "Required parameter id must be specified.");
      }

      @Override
      public Patch setUserIp(String userIp) {
        return (Patch) super.setUserIp(userIp);
      }

      @Override
      public Patch setOauthToken(String oauthToken) {
        return (Patch) super.setOauthToken(oauthToken);
      }

      @Override
      public Patch setQuotaUser(String quotaUser) {
        return (Patch) super.setQuotaUser(quotaUser);
      }

      @Override
      public Patch setKey(String key) {
        return (Patch) super.setKey(key);
      }

      @Override
      public Patch setPrettyPrint(Boolean prettyPrint) {
        return (Patch) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Patch setAlt(String alt) {
        return (Patch) super.setAlt(alt);
      }

      @Override
      public Patch setFields(String fields) {
        return (Patch) super.setFields(fields);
      }

      /** The ID of the timeline item. */
      @com.google.api.client.util.Key
      private String id;

      /** The ID of the timeline item.
       */
      public String getId() {
        return id;
      }

      /** The ID of the timeline item. */
      public Patch setId(String id) {
        this.id = id;
        return this;
      }

    }

  }

  /**
   * Builder for {@link Glass}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport
     * @param jsonFactory JSON factory
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(HttpTransport transport, JsonFactory jsonFactory,
        HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link Glass}. */
    @Override
    public Glass build() {
      return new Glass(getTransport(),
          getHttpRequestInitializer(),
          getRootUrl(),
          getServicePath(),
          getObjectParser(),
          getGoogleClientRequestInitializer(),
          getApplicationName(),
          getSubscriptionStore(),
          getSuppressPatternChecks());
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    /**
     * Set the {@link GlassRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setGlassRequestInitializer(
        GlassRequestInitializer glassRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(glassRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }

    /**
     * @since 1.13
     */
    @Override
    public Builder setSubscriptionStore(SubscriptionStore subscriptionStore) {
      return (Builder) super.setSubscriptionStore(subscriptionStore);
    }
  }
}
