/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.glass.model;

import com.google.api.client.json.GenericJson;

/**
 * A person or group that can be used as a creator or a share target.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Glass Mirror API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Entity extends GenericJson {

  /**
   * The type for this entity. This is used for sorting in UIs. Allowed values are: - INDIVIDUAL -
   * Represents a single person. This is the default.  - GROUP - Represents more than a single
   * person.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String type;

  /**
   * The type of resource. This is always glass#entity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Set of image urls to display for an entity. Most entities will have a single image, but a
   * "group" entity may include up to 8 image urls and they will be re-sized and cropped into a
   * mosaic on the client.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> imageUrls;

  /**
   * The ID of the application that created this entity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String source;

  /**
   * The name to display for this entity.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String displayName;

  /**
   * A list of MIME types that a share target can handle. The share target will be shown to the user
   * if any of its acceptTypes matches any of the types of the attachments on the item. If no
   * acceptTypes are given, the share target will be shown for all items.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> acceptTypes;

  /**
   * An ID for this entity. This is generated by the application and is treated as an opaque token
   * by Glass.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The type for this entity. This is used for sorting in UIs. Allowed values are: - INDIVIDUAL -
   * Represents a single person. This is the default.  - GROUP - Represents more than a single
   * person.
   * The value returned may be {@code null}.
   */
  public String getType() {
    return type;
  }

  /**
   * The type for this entity. This is used for sorting in UIs. Allowed values are: - INDIVIDUAL -
   * Represents a single person. This is the default.  - GROUP - Represents more than a single
   * person.
   * The value set may be {@code null}.
   */
  public Entity setType(String type) {
    this.type = type;
    return this;
  }

  /**
   * The type of resource. This is always glass#entity.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The type of resource. This is always glass#entity.
   * The value set may be {@code null}.
   */
  public Entity setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Set of image urls to display for an entity. Most entities will have a single image, but a
   * "group" entity may include up to 8 image urls and they will be re-sized and cropped into a
   * mosaic on the client.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getImageUrls() {
    return imageUrls;
  }

  /**
   * Set of image urls to display for an entity. Most entities will have a single image, but a
   * "group" entity may include up to 8 image urls and they will be re-sized and cropped into a
   * mosaic on the client.
   * The value set may be {@code null}.
   */
  public Entity setImageUrls(java.util.List<String> imageUrls) {
    this.imageUrls = imageUrls;
    return this;
  }

  /**
   * The ID of the application that created this entity.
   * The value returned may be {@code null}.
   */
  public String getSource() {
    return source;
  }

  /**
   * The ID of the application that created this entity.
   * The value set may be {@code null}.
   */
  public Entity setSource(String source) {
    this.source = source;
    return this;
  }

  /**
   * The name to display for this entity.
   * The value returned may be {@code null}.
   */
  public String getDisplayName() {
    return displayName;
  }

  /**
   * The name to display for this entity.
   * The value set may be {@code null}.
   */
  public Entity setDisplayName(String displayName) {
    this.displayName = displayName;
    return this;
  }

  /**
   * A list of MIME types that a share target can handle. The share target will be shown to the user
   * if any of its acceptTypes matches any of the types of the attachments on the item. If no
   * acceptTypes are given, the share target will be shown for all items.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getAcceptTypes() {
    return acceptTypes;
  }

  /**
   * A list of MIME types that a share target can handle. The share target will be shown to the user
   * if any of its acceptTypes matches any of the types of the attachments on the item. If no
   * acceptTypes are given, the share target will be shown for all items.
   * The value set may be {@code null}.
   */
  public Entity setAcceptTypes(java.util.List<String> acceptTypes) {
    this.acceptTypes = acceptTypes;
    return this;
  }

  /**
   * An ID for this entity. This is generated by the application and is treated as an opaque token
   * by Glass.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * An ID for this entity. This is generated by the application and is treated as an opaque token
   * by Glass.
   * The value set may be {@code null}.
   */
  public Entity setId(String id) {
    this.id = id;
    return this;
  }

}
