/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.glass.model;

import com.google.api.client.json.GenericJson;

/**
 * A custom menu item that can be presented to the user by a TimelineItem.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Glass Mirror API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class MenuItem extends GenericJson {

  /**
   * Controls the behavior when the user picks the menu option. Allowed values are: - CUSTOM -
   * Custom action set by the service, trigger an UPDATE notification containing the id of the
   * selected menu item. This is the default value.  - Built-in actions:   - REPLY - Initiate a
   * reply to the Timeline Item using the voice recording UI. The creator attribute must be set in
   * the Timeline Item for this menu to be available.  - REPLY_ALL - Same behavior as REPLY. The
   * original Timeline item's Share Target will be added to the reply item.  - DELETE - Delete the
   * Timeline item.  - SHARE - Share the Timeline item with the available Share Targets.  -
   * READ_ALOUD - Read the Timeline item's text aloud.  - VOICE_CALL - Initiate a phone call using
   * the Timeline item's creator.phone_number attribute as recipient.  - NAVIGATE - Navigate to the
   * Timeline item's location.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String action;

  /**
   * For CUSTOM items, a list of values controlling the appearance of the menu item in each of its
   * states. A value for the DEFAULT state must be provided. If the PENDING or CONFIRMED states are
   * missing, they will not be shown.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<MenuValue> values;

  static {
    // hack to force ProGuard to consider MenuValue used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(MenuValue.class);
  }

  /**
   * The current state of this menu item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String state;

  /**
   * The ID for this menu item. This is generated by the application and is treated as an opaque
   * token by Glass.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * Controls the behavior when the user picks the menu option. Allowed values are: - CUSTOM -
   * Custom action set by the service, trigger an UPDATE notification containing the id of the
   * selected menu item. This is the default value.  - Built-in actions:   - REPLY - Initiate a
   * reply to the Timeline Item using the voice recording UI. The creator attribute must be set in
   * the Timeline Item for this menu to be available.  - REPLY_ALL - Same behavior as REPLY. The
   * original Timeline item's Share Target will be added to the reply item.  - DELETE - Delete the
   * Timeline item.  - SHARE - Share the Timeline item with the available Share Targets.  -
   * READ_ALOUD - Read the Timeline item's text aloud.  - VOICE_CALL - Initiate a phone call using
   * the Timeline item's creator.phone_number attribute as recipient.  - NAVIGATE - Navigate to the
   * Timeline item's location.
   * The value returned may be {@code null}.
   */
  public String getAction() {
    return action;
  }

  /**
   * Controls the behavior when the user picks the menu option. Allowed values are: - CUSTOM -
   * Custom action set by the service, trigger an UPDATE notification containing the id of the
   * selected menu item. This is the default value.  - Built-in actions:   - REPLY - Initiate a
   * reply to the Timeline Item using the voice recording UI. The creator attribute must be set in
   * the Timeline Item for this menu to be available.  - REPLY_ALL - Same behavior as REPLY. The
   * original Timeline item's Share Target will be added to the reply item.  - DELETE - Delete the
   * Timeline item.  - SHARE - Share the Timeline item with the available Share Targets.  -
   * READ_ALOUD - Read the Timeline item's text aloud.  - VOICE_CALL - Initiate a phone call using
   * the Timeline item's creator.phone_number attribute as recipient.  - NAVIGATE - Navigate to the
   * Timeline item's location.
   * The value set may be {@code null}.
   */
  public MenuItem setAction(String action) {
    this.action = action;
    return this;
  }

  /**
   * For CUSTOM items, a list of values controlling the appearance of the menu item in each of its
   * states. A value for the DEFAULT state must be provided. If the PENDING or CONFIRMED states are
   * missing, they will not be shown.
   * The value returned may be {@code null}.
   */
  public java.util.List<MenuValue> getValues() {
    return values;
  }

  /**
   * For CUSTOM items, a list of values controlling the appearance of the menu item in each of its
   * states. A value for the DEFAULT state must be provided. If the PENDING or CONFIRMED states are
   * missing, they will not be shown.
   * The value set may be {@code null}.
   */
  public MenuItem setValues(java.util.List<MenuValue> values) {
    this.values = values;
    return this;
  }

  /**
   * The current state of this menu item.
   * The value returned may be {@code null}.
   */
  public String getState() {
    return state;
  }

  /**
   * The current state of this menu item.
   * The value set may be {@code null}.
   */
  public MenuItem setState(String state) {
    this.state = state;
    return this;
  }

  /**
   * The ID for this menu item. This is generated by the application and is treated as an opaque
   * token by Glass.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The ID for this menu item. This is generated by the application and is treated as an opaque
   * token by Glass.
   * The value set may be {@code null}.
   */
  public MenuItem setId(String id) {
    this.id = id;
    return this;
  }

}
