/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.glass.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Each item in the Glass user's timeline is represented as a TimelineItem JSON structure, described
 * below.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Glass Mirror API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class TimelineItem extends GenericJson {

  /**
   * The time that should be displayed when this item is viewed in the timeline, formatted according
   * to RFC 3339. This user's timeline is sorted chronlogically on display time, so this will also
   * determine where the item is displayed in the timeline. If not present the display time defaults
   * to the "updated" time.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime displayTime;

  /**
   * A list of users or groups that this item has been shared with.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Entity> shareTargets;

  static {
    // hack to force ProGuard to consider Entity used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Entity.class);
  }

  /**
   * If this item was generated as a reply to another item, this field will be set to the id of the
   * item being replied to. This can be used to attach a reply to the appropriate conversation or
   * post.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String inReplyTo;

  /**
   * The time at which this item was last modified, formated according to RFC 3339.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime updated;

  /**
   * Controls how notifications for this item are presented on the device. If this is missing, no
   * notification will be generated.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private NotificationConfig notification;

  /**
   * The ID of the timeline item. This is unique within a user's timeline.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * The user or group that created this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Entity creator;

  /**
   * The type of resource. This is always glass#timelineItem.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * HTML content for this item. If both text and HTML are provided for an item, the HTML will be
   * rendered. If more than one HTML string is provided, the item will be displayed as a bundle.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<String> html;

  /**
   * When true, indicates this item is pinned, which means it's grouped alongside "active" items
   * like navigation and hangouts, on the opposite side of the home screen from historical (non-
   * pinned) timeline items.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isPinned;

  /**
   * The bundle ID for this item. Services can specify a bundleId to group many items together. They
   * appear under a single top-level item on the Glass Device.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String bundleId;

  /**
   * The speakable version of the content of this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String speakableText;

  /**
   * The title of this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * When true, indicates this item is deleted, and only the id field is set.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isDeleted;

  /**
   * A URL that can be used to retrieve this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * ETag for this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String etag;

  /**
   * The geographic location associated with this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Location location;

  /**
   * A list of media attachments associated with this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Attachment> attachments;

  static {
    // hack to force ProGuard to consider Attachment used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Attachment.class);
  }

  /**
   * A list of menu items that will be presented to the user when this item is selected in the
   * timeline.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<MenuItem> menuItems;

  static {
    // hack to force ProGuard to consider MenuItem used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(MenuItem.class);
  }

  /**
   * The time at which this item was created, formated according to RFC 3339.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime created;

  /**
   * Text content of this item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String text;

  /**
   * The time that should be displayed when this item is viewed in the timeline, formatted according
   * to RFC 3339. This user's timeline is sorted chronlogically on display time, so this will also
   * determine where the item is displayed in the timeline. If not present the display time defaults
   * to the "updated" time.
   * The value returned may be {@code null}.
   */
  public DateTime getDisplayTime() {
    return displayTime;
  }

  /**
   * The time that should be displayed when this item is viewed in the timeline, formatted according
   * to RFC 3339. This user's timeline is sorted chronlogically on display time, so this will also
   * determine where the item is displayed in the timeline. If not present the display time defaults
   * to the "updated" time.
   * The value set may be {@code null}.
   */
  public TimelineItem setDisplayTime(DateTime displayTime) {
    this.displayTime = displayTime;
    return this;
  }

  /**
   * A list of users or groups that this item has been shared with.
   * The value returned may be {@code null}.
   */
  public java.util.List<Entity> getShareTargets() {
    return shareTargets;
  }

  /**
   * A list of users or groups that this item has been shared with.
   * The value set may be {@code null}.
   */
  public TimelineItem setShareTargets(java.util.List<Entity> shareTargets) {
    this.shareTargets = shareTargets;
    return this;
  }

  /**
   * If this item was generated as a reply to another item, this field will be set to the id of the
   * item being replied to. This can be used to attach a reply to the appropriate conversation or
   * post.
   * The value returned may be {@code null}.
   */
  public String getInReplyTo() {
    return inReplyTo;
  }

  /**
   * If this item was generated as a reply to another item, this field will be set to the id of the
   * item being replied to. This can be used to attach a reply to the appropriate conversation or
   * post.
   * The value set may be {@code null}.
   */
  public TimelineItem setInReplyTo(String inReplyTo) {
    this.inReplyTo = inReplyTo;
    return this;
  }

  /**
   * The time at which this item was last modified, formated according to RFC 3339.
   * The value returned may be {@code null}.
   */
  public DateTime getUpdated() {
    return updated;
  }

  /**
   * The time at which this item was last modified, formated according to RFC 3339.
   * The value set may be {@code null}.
   */
  public TimelineItem setUpdated(DateTime updated) {
    this.updated = updated;
    return this;
  }

  /**
   * Controls how notifications for this item are presented on the device. If this is missing, no
   * notification will be generated.
   * The value returned may be {@code null}.
   */
  public NotificationConfig getNotification() {
    return notification;
  }

  /**
   * Controls how notifications for this item are presented on the device. If this is missing, no
   * notification will be generated.
   * The value set may be {@code null}.
   */
  public TimelineItem setNotification(NotificationConfig notification) {
    this.notification = notification;
    return this;
  }

  /**
   * The ID of the timeline item. This is unique within a user's timeline.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The ID of the timeline item. This is unique within a user's timeline.
   * The value set may be {@code null}.
   */
  public TimelineItem setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * The user or group that created this item.
   * The value returned may be {@code null}.
   */
  public Entity getCreator() {
    return creator;
  }

  /**
   * The user or group that created this item.
   * The value set may be {@code null}.
   */
  public TimelineItem setCreator(Entity creator) {
    this.creator = creator;
    return this;
  }

  /**
   * The type of resource. This is always glass#timelineItem.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The type of resource. This is always glass#timelineItem.
   * The value set may be {@code null}.
   */
  public TimelineItem setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * HTML content for this item. If both text and HTML are provided for an item, the HTML will be
   * rendered. If more than one HTML string is provided, the item will be displayed as a bundle.
   * The value returned may be {@code null}.
   */
  public java.util.List<String> getHtml() {
    return html;
  }

  /**
   * HTML content for this item. If both text and HTML are provided for an item, the HTML will be
   * rendered. If more than one HTML string is provided, the item will be displayed as a bundle.
   * The value set may be {@code null}.
   */
  public TimelineItem setHtml(java.util.List<String> html) {
    this.html = html;
    return this;
  }

  /**
   * When true, indicates this item is pinned, which means it's grouped alongside "active" items
   * like navigation and hangouts, on the opposite side of the home screen from historical (non-
   * pinned) timeline items.
   * The value returned may be {@code null}.
   */
  public Boolean getIsPinned() {
    return isPinned;
  }

  /**
   * When true, indicates this item is pinned, which means it's grouped alongside "active" items
   * like navigation and hangouts, on the opposite side of the home screen from historical (non-
   * pinned) timeline items.
   * The value set may be {@code null}.
   */
  public TimelineItem setIsPinned(Boolean isPinned) {
    this.isPinned = isPinned;
    return this;
  }

  /**
   * The bundle ID for this item. Services can specify a bundleId to group many items together. They
   * appear under a single top-level item on the Glass Device.
   * The value returned may be {@code null}.
   */
  public String getBundleId() {
    return bundleId;
  }

  /**
   * The bundle ID for this item. Services can specify a bundleId to group many items together. They
   * appear under a single top-level item on the Glass Device.
   * The value set may be {@code null}.
   */
  public TimelineItem setBundleId(String bundleId) {
    this.bundleId = bundleId;
    return this;
  }

  /**
   * The speakable version of the content of this item.
   * The value returned may be {@code null}.
   */
  public String getSpeakableText() {
    return speakableText;
  }

  /**
   * The speakable version of the content of this item.
   * The value set may be {@code null}.
   */
  public TimelineItem setSpeakableText(String speakableText) {
    this.speakableText = speakableText;
    return this;
  }

  /**
   * The title of this item.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * The title of this item.
   * The value set may be {@code null}.
   */
  public TimelineItem setTitle(String title) {
    this.title = title;
    return this;
  }

  /**
   * When true, indicates this item is deleted, and only the id field is set.
   * The value returned may be {@code null}.
   */
  public Boolean getIsDeleted() {
    return isDeleted;
  }

  /**
   * When true, indicates this item is deleted, and only the id field is set.
   * The value set may be {@code null}.
   */
  public TimelineItem setIsDeleted(Boolean isDeleted) {
    this.isDeleted = isDeleted;
    return this;
  }

  /**
   * A URL that can be used to retrieve this item.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * A URL that can be used to retrieve this item.
   * The value set may be {@code null}.
   */
  public TimelineItem setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * ETag for this item.
   * The value returned may be {@code null}.
   */
  public String getEtag() {
    return etag;
  }

  /**
   * ETag for this item.
   * The value set may be {@code null}.
   */
  public TimelineItem setEtag(String etag) {
    this.etag = etag;
    return this;
  }

  /**
   * The geographic location associated with this item.
   * The value returned may be {@code null}.
   */
  public Location getLocation() {
    return location;
  }

  /**
   * The geographic location associated with this item.
   * The value set may be {@code null}.
   */
  public TimelineItem setLocation(Location location) {
    this.location = location;
    return this;
  }

  /**
   * A list of media attachments associated with this item.
   * The value returned may be {@code null}.
   */
  public java.util.List<Attachment> getAttachments() {
    return attachments;
  }

  /**
   * A list of media attachments associated with this item.
   * The value set may be {@code null}.
   */
  public TimelineItem setAttachments(java.util.List<Attachment> attachments) {
    this.attachments = attachments;
    return this;
  }

  /**
   * A list of menu items that will be presented to the user when this item is selected in the
   * timeline.
   * The value returned may be {@code null}.
   */
  public java.util.List<MenuItem> getMenuItems() {
    return menuItems;
  }

  /**
   * A list of menu items that will be presented to the user when this item is selected in the
   * timeline.
   * The value set may be {@code null}.
   */
  public TimelineItem setMenuItems(java.util.List<MenuItem> menuItems) {
    this.menuItems = menuItems;
    return this;
  }

  /**
   * The time at which this item was created, formated according to RFC 3339.
   * The value returned may be {@code null}.
   */
  public DateTime getCreated() {
    return created;
  }

  /**
   * The time at which this item was created, formated according to RFC 3339.
   * The value set may be {@code null}.
   */
  public TimelineItem setCreated(DateTime created) {
    this.created = created;
    return this;
  }

  /**
   * Text content of this item.
   * The value returned may be {@code null}.
   */
  public String getText() {
    return text;
  }

  /**
   * Text content of this item.
   * The value set may be {@code null}.
   */
  public TimelineItem setText(String text) {
    this.text = text;
    return this;
  }

}
